Functions

Struct Functions 

pub struct Functions {
    pub resume: LuaFunction,
    pub wrap: LuaFunction,
    pub spawn: LuaFunction,
    pub defer: LuaFunction,
    pub cancel: LuaFunction,
    pub exit: LuaFunction,
}
A collection of lua functions that may be called to interact with a [Scheduler].

Note that these may all be implemented using LuaSchedulerExt, however, this struct is implemented using internal (non-public) APIs, and generally has better performance.

Fields

resume: LuaFunction

Implementation of coroutine.resume that handles async polling properly.

Defers onto the scheduler queue if the thread calls an async function.

wrap: LuaFunction

Implementation of coroutine.wrap that handles async polling properly.

Defers onto the scheduler queue if the thread calls an async function.

spawn: LuaFunction

Resumes a function / thread once instantly, and runs until first yield.

Spawns onto the scheduler queue if not completed.

defer: LuaFunction

Defers a function / thread onto the scheduler queue.

Does not resume instantly, only adds to the queue.

cancel: LuaFunction

Cancels a function / thread, removing it from the queue.

exit: LuaFunction

Exits the scheduler, stopping all other threads and closing the scheduler.

Yields the calling thread to ensure that it does not continue.

Implementations

Source

impl Functions

pub fn new(lua: Lua) -> LuaResult<Self>

Creates a new collection of Lua functions that may be called to interact with a [Scheduler].

Errors

Errors when out of memory, or if default Lua globals are missing.

Panics

Panics when the given Lua instance does not have an attached [Scheduler].

Source

impl Functions

pub fn inject_compat(&self, lua: &Lua) -> LuaResult<()>

Injects [Scheduler]-compatible functions into the given Lua instance.

This will overwrite the following functions:

  • coroutine.resume
  • coroutine.wrap
Errors

Errors when out of memory, or if default Lua globals are missing.