pub struct ThreadId { /* private fields */ }Expand description
Opaque and unique ID representing a LuaThread.
Typically used for associating metadata with a thread in a structure such as a HashMap<ThreadId, ...>.
Note that holding a ThreadId does not prevent the thread from being garbage collected.
The actual thread may or may not still exist and be active at any given point in time.