pub struct Functions {
pub resume: LuaFunction,
pub wrap: LuaFunction,
pub spawn: LuaFunction,
pub defer: LuaFunction,
pub cancel: LuaFunction,
pub exit: LuaFunction,
}Expand description
A collection of lua functions that may be called to interact with a [Scheduler].
Note that these may all be implemented using LuaSchedulerExt, however, this struct
is implemented using internal (non-public) APIs, and generally has better performance.
Fields
resume: LuaFunctionImplementation of coroutine.resume that handles async polling properly.
Defers onto the scheduler queue if the thread calls an async function.
wrap: LuaFunctionImplementation of coroutine.wrap that handles async polling properly.
Defers onto the scheduler queue if the thread calls an async function.
spawn: LuaFunctionResumes a function / thread once instantly, and runs until first yield.
Spawns onto the scheduler queue if not completed.
defer: LuaFunctionDefers a function / thread onto the scheduler queue.
Does not resume instantly, only adds to the queue.
cancel: LuaFunctionCancels a function / thread, removing it from the queue.
exit: LuaFunctionExits the scheduler, stopping all other threads and closing the scheduler.
Yields the calling thread to ensure that it does not continue.
Implementations