pub trait IntoLuaThread {
// Required method
fn into_lua_thread(self, lua: &Lua) -> LuaResult<LuaThread>;
}Expand description
Trait for any struct that can be turned into an LuaThread
and passed to the scheduler, implemented for the following types:
- Lua threads (
LuaThread) - Lua functions (
LuaFunction) - Lua chunks (
LuaChunk)
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".