IntoLuaThread

Trait IntoLuaThread 

pub trait IntoLuaThread {
    // Required method
    fn into_lua_thread(self, lua: &Lua) -> LuaResult<LuaThread>;
}
Trait for any struct that can be turned into an LuaThread and passed to the scheduler, implemented for the following types:

Required Methods

fn into_lua_thread(self, lua: &Lua) -> LuaResult<LuaThread>

Converts the value into a Lua thread.

Errors

Errors when out of memory.

Implementations on Foreign Types

Source

impl IntoLuaThread for LuaChunk<'_>

Source

impl IntoLuaThread for LuaFunction

Source

impl IntoLuaThread for LuaThread

Source

impl<T> IntoLuaThread for &T
where T: IntoLuaThread + Clone,

Implementors